@@ -1,10 +1,8 @@
-/* globals Chart:false, feather:false */
+/* globals Chart:false */
 
 (() => {
   'use strict'
 
-  feather.replace({ 'aria-hidden': 'true' })
-
   // Graphs
   const ctx = document.getElementById('myChart')
   // eslint-disable-next-line no-unused-vars
@@ -38,15 +36,13 @@
       }]
     },
     options: {
-      scales: {
-        yAxes: [{
-          ticks: {
-            beginAtZero: false
-          }
-        }]
-      },
-      legend: {
-        display: false
+      plugins: {
+        legend: {
+          display: false
+        },
+        tooltip: {
+          boxPadding: 3
+        }
       }
     }
   })
